@@ -116,12 +116,13 @@ class CreateDPDShipping(Wizard):
                         })
                 break
             except Fault as e:
-                tag = etree.QName(e.detail[0].tag)
-                if tag.localname == 'authenticationFault':
-                    count += 1
-                    credential.update_token()
-                else:
-                    raise
+                if e.detail:
+                    tag = etree.QName(e.detail[0].tag)
+                    if tag.localname == 'authenticationFault':
+                        count += 1
+                        credential.update_token()
+                        continue
+                raise
         else:
             self.raise_user_error('can_not_login', {
                     'credential': credential.rec_name,
@@ -149,7 +150,7 @@ class CreateDPDShipping(Wizard):
         for package, label, parcel in zip_longest(packages, labels, parcels):
             package.shipping_label = fields.Binary.cast(label.getvalue())
             package.shipping_reference = parcel.parcelLabelNumber
-        Package.save(shipment.root_packages)
+        Package.save(packages)
         shipment.save()
 
         return 'end'
@@ -176,12 +177,12 @@ class CreateDPDShipping(Wizard):
 
     def shipping_party(self, party, address):
         shipping_party = {
-            'name1': address.party_full_name[:50],
+            'name1': address.party_full_name[:35],
             'name2': '',
             'street': ' '.join((address.street or '').splitlines())[:35],
             'country': address.country.code if address.country else '',
             'zipCode': address.zip[:9],
-            'city': address.city[:50],
+            'city': address.city[:35],
             }
         if party.full_name != address.party_full_name:
             shipping_party['name2'] = party.full_name[:35]
@@ -194,8 +195,8 @@ class CreateDPDShipping(Wizard):
                 email = mechanism.value
         if phone:
             shipping_party['phone'] = phone[:30]
-        if email:
-            shipping_party['email'] = email[:50]
+        if len(email) <= 50:
+            shipping_party['email'] = email
 
         return shipping_party
 
